abacusai.api_class.refresh — AbacusAI documentation

# `abacusai.api_class.refresh`

## Module Contents

### Classes

`FeatureGroupExportConfig` | Helper class that provides a standard way to create an ABC using
`FileConnectorExportConfig` | Helper class that provides a standard way to create an ABC using
`DatabaseConnectorExportConfig` | Helper class that provides a standard way to create an ABC using
`_FeatureGroupExportConfigFactory` | Helper class that provides a standard way to create an ABC using

class abacusai.api_class.refresh.FeatureGroupExportConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  connector_type: abacusai.api_class.enums.ConnectorType
  classmethod _get_builder()

class abacusai.api_class.refresh.FileConnectorExportConfig

  Bases: `FeatureGroupExportConfig`

  Helper class that provides a standard way to create an ABC using inheritance.

  location: str
  export_file_format: str
  __post_init__()
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

class abacusai.api_class.refresh.DatabaseConnectorExportConfig

  Bases: `FeatureGroupExportConfig`

  Helper class that provides a standard way to create an ABC using inheritance.

  database_connector_id: str
  mode: str
  object_name: str
  id_column: str
  additional_id_columns: List[str]
  data_columns: Dict[str, str]
  __post_init__()
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

class abacusai.api_class.refresh._FeatureGroupExportConfigFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key = 'connector_type'
  config_class_map